SyncError

Enum SyncError 

#[non_exhaustive]
pub enum SyncError { OutboxFull { capacity: usize, current: usize, }, BufferFull(usize), Transport(String), Conflict { entity_type: String, entity_id: String, description: String, }, NotInitialized, Serialization(String), Storage(String), InvalidConfig(String), DuplicateEvent(String), SequenceOutOfRange { requested: u64, head: u64, }, }
Errors that can occur during sync operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


OutboxFull

The outbox has reached its maximum capacity.

Fields

capacity: usize

Maximum allowed events.

current: usize

Current event count.



BufferFull(usize)

The event buffer has reached its maximum capacity (informational; old events are evicted).



Transport(String)

A transport-level error occurred during push or pull.



Conflict

A conflict was detected between local and remote events.

Fields

entity_type: String

The type of entity involved.

entity_id: String

The identifier of the entity.

description: String

Human-readable conflict description.



NotInitialized

The sync engine has not been initialized.



Serialization(String)

A serialization or deserialization error occurred.



Storage(String)

A local storage operation failed (for durable outbox persistence).



InvalidConfig(String)

An invalid configuration value was provided.



DuplicateEvent(String)

An event with a duplicate ID was detected.



SequenceOutOfRange

The requested sequence number is out of range.

Fields

requested: u64

The sequence that was requested.

head: u64

The current head sequence.